==> scala-2.1.2.tar.gz: scala/runtime/BoxedLongArray.scala <==
/*                     __                                               *\
**     ________ ___   / /  ___     Scala API                            **
**    / __/ __// _ | / /  / _ |    (c) 2002-2006, LAMP/EPFL             **
**  __\ \/ /__/ __ |/ /__/ __ |                                         **
** /____/\___/_/ |_/____/_/ | |                                         **
**                          |/                                          **
\*                                                                      */

// $Id: BoxedLongArray.scala 6748 2006-03-14 15:21:50Z odersky $


package scala.runtime;


[serializable]
final class BoxedLongArray(val value: Array[Long]) extends BoxedArray {

  def length: Int = value.length;

  def apply(index: Int): Object = BoxedLong.box(value(index));

  def update(index: Int, elem: Object): Unit = { 
    value(index) = elem.asInstanceOf[BoxedNumber].longValue() 
  }

  def unbox(elemTag: String): Object = value;

  override def equals(other: Any) = (
    value == other ||
    other.isInstanceOf[BoxedLongArray] && value == other.asInstanceOf[BoxedLongArray].value
  );

  override def hashCode(): Int = value.hashCode();
       
  def subArray(start: Int, end: Int): Array[Long] = {
    val result = new Array[Long](end - start);
    Array.copy(value, 0, result, 0, end - start)
    result
  }    

  def filter(p: Any => Boolean): Array[Long] = {
    val include = new Array[Boolean](value.length);
    var len = 0;
    var i = 0;
    while (i < value.length) {
      if (p(value(i))) { include(i) = true; len = len + 1 }
      i = i + 1
    }
    val result = new Array[Long](len);
    len = 0;
    i = 0;
    while (len < result.length) {
      if (include(i)) { result(len) = value(i); len = len + 1 }
      i = i + 1
    }
    result
  }
}

==> scala-2.1.8.tar.gz: scala/runtime/BoxedLongArray.scala <==
/*                     __                                               *\
**     ________ ___   / /  ___     Scala API                            **
**    / __/ __// _ | / /  / _ |    (c) 2002-2006, LAMP/EPFL             **
**  __\ \/ /__/ __ |/ /__/ __ |                                         **
** /____/\___/_/ |_/____/_/ | |                                         **
**                          |/                                          **
\*                                                                      */

// $Id: BoxedLongArray.scala 7454 2006-05-19 12:58:35Z spoon $


package scala.runtime;


[serializable]
final class BoxedLongArray(val value: Array[Long]) extends BoxedArray {

  def length: Int = value.length;

  def apply(index: Int): Object = BoxedLong.box(value(index));

  def update(index: Int, elem: Object): Unit = { 
    value(index) = elem.asInstanceOf[BoxedNumber].longValue() 
  }

  def unbox(elemTag: String): Object = value;
  def unbox(elemClass: Class): Object = value;

  override def equals(other: Any) = (
    value == other ||
    other.isInstanceOf[BoxedLongArray] && value == other.asInstanceOf[BoxedLongArray].value
  );

  override def hashCode(): Int = value.hashCode();
       
  def subArray(start: Int, end: Int): Array[Long] = {
    val result = new Array[Long](end - start);
    Array.copy(value, start, result, 0, end - start)
    result
  }    

  def filter(p: Any => Boolean): Array[Long] = {
    val include = new Array[Boolean](value.length);
    var len = 0;
    var i = 0;
    while (i < value.length) {
      if (p(value(i))) { include(i) = true; len = len + 1 }
      i = i + 1
    }
    val result = new Array[Long](len);
    len = 0;
    i = 0;
    while (len < result.length) {
      if (include(i)) { result(len) = value(i); len = len + 1 }
      i = i + 1
    }
    result
  }
}
